@@ -85,7 +85,7 @@ VERSIONS = {
 }
 
 
-def spawn(name, digitalocean_token):
+def spawn_cloud(name, digitalocean_token):
     """Spawn the understory on a new droplet."""
     cli = do.Client(digitalocean_token)
     key = do.get_key(cli)
@@ -100,22 +100,55 @@ def spawn(name, digitalocean_token):
             break
     print(ip_address, flush=True)
 
-    def process_out(line):
+    print("spawning gaea..", flush=True)
+    root_ssh = do.get_ssh("root", ip_address)
+    root_ssh("adduser gaea --disabled-login --gecos gaea")
+    root_ssh('echo "gaea  ALL=NOPASSWD: ALL" | tee -a /etc/sudoers.d/01_gaea')
+
+    gaea_ssh_dir = "/home/gaea/.ssh"
+    root_ssh(f"mkdir {gaea_ssh_dir}")
+    root_ssh(f"cp /root/.ssh/authorized_keys {gaea_ssh_dir}")
+    root_ssh(f"chown gaea:gaea {gaea_ssh_dir} -R")
+
+    root_ssh("apt install fuse -y")
+
+    print("spawning the understory..", flush=True)
+    print("__file__:", __file__)
+    do.scp("gaea", f"gaea@{ip_address}:")
+    gaea_ssh = do.get_ssh("gaea", ip_address)
+    gaea_ssh("chown gaea:gaea gaea")
+    gaea_ssh("chmod u+x gaea")
+    gaea_ssh(f"./gaea setup {digitalocean_token}", process_out(ip_address))
+
+
+def spawn_local():
+    # sh.sudo("bash", "spawn.sh")  # TODO FIXME
+
+    # sh.scp("-i", "gaea_key", "gaea", "gaea@localhost:")
+
+    # TODO sh bake
+    def ssh(command):
+        sh.ssh(
+            "gaea@localhost", "-i", "gaea_key", command, _out=process_out("localhost")
+        )
+
+    # ssh("chown gaea:gaea gaea")
+    # ssh("chmod u+x gaea")
+    ssh("./gaea setup")
+
+
+def process_out(host):
+    def process(line):
         if "?secret=" in line:
             secret = line.partition("=")[2]
             # TODO osx appends a trailing newline (?)
-            webbrowser.open(f"https://{ip_address}?secret={secret}")
+            webbrowser.open(f"https://{host}?secret={secret}")
         print(line, end="", flush=True)
 
-    print("spawning gaea..", flush=True)
-    do.get_ssh("root", ip_address, process_out)(
-        "wget https://raw.githubusercontent.com/canopy/gaea/main/spawn.sh -qO- | bash",
-    )
-    print("spawning the understory..", flush=True)
-    do.get_ssh("gaea", ip_address, process_out)(f"./gaea setup {digitalocean_token}")
+    return process
 
 
-def setup(digitalocean_token):
+def setup(digitalocean_token=""):
     """Set up the understory on this system."""
     # TODO ensure in home directory
     print("setting up base system..")
@@ -172,6 +205,7 @@ class Gaea:
         self.home_dir = pathlib.Path(home_dir)
         self.apps_dir = self.home_dir / "apps"
         self.sites_dir = self.home_dir / "sites"
+        self.working_dir = self.home_dir / "working"
         self.system_dir = self.home_dir / "system"
         self.bin_dir = self.system_dir / "bin"
         self.env_dir = self.system_dir / "env"
@@ -350,7 +384,7 @@ class Gaea:
         # TODO                               "user": "gaea"}
         self._write_supervisor_conf("servers", supervisor)
 
-    def setup_gaea(self, digitalocean_token):
+    def setup_gaea(self, digitalocean_token=""):
         """Set up the gaea web app."""
         ip = sh.hostname("-I").split()[0]
         secret = "".join(
