@@ -179,7 +179,7 @@ class WebsiteDNS:
         else:
             try:
                 cli.create_domain(domain_name, get_ip())
-            except DomainExistsError:
+            except gaea.do.DomainExistsError:
                 for record in cli.get_domain_records(domain_name):
                     if record["name"] == "@" and record["type"] == "A":
                         break
@@ -244,6 +244,7 @@ class Applications:
             install_app,
             app,
             str(tx.gaea.home_dir),
+            str(tx.gaea.working_dir),
             tx.gaea.get_config()["tokens"]["github"],
         )
         return "installing and restarting.."
@@ -268,30 +269,57 @@ class Applications:
         # XXX       app_url, _cwd=tx.gaea.home_dir)
 
 
-def install_app(app, home_dir, github_token):
+def install_app(app, home_dir, working_dir, github_token):
     if app.startswith("https://"):  # Git repo
         pass  # TODO
     elif "/" in app:  # GitHub project
-        gh_prefix = f"https://api.github.com/repos/{app}/releases"
-        gh_token_header = f"token {github_token}"
-        gh_headers = {
-            "Accept": "application/vnd.github.v3+json",
-            "Authorization": gh_token_header,
-        }
-        asset = web.get(f"{gh_prefix}/latest", headers=gh_headers).json["assets"][0]
-        sh.wget(
-            f"{gh_prefix}/assets/{asset['id']}",
-            "-O",
-            asset["name"],
-            "--header",
-            "Accept: application/octet-stream",
-            "--header",
-            f"Authorization: {gh_token_header}",
+        working_dir = working_dir
+        sh.git("clone", f"https://github.com/{app}.git", _cwd=working_dir)
+        sh.poetry("install", _cwd=working_dir + f"/{app}")
+
+        # XXX gh_prefix = f"https://api.github.com/repos/{app}/releases"
+        # XXX gh_token_header = f"token {github_token}"
+        # XXX gh_headers = {
+        # XXX     "Accept": "application/vnd.github.v3+json",
+        # XXX     "Authorization": gh_token_header,
+        # XXX }
+        # XXX asset = web.get(f"{gh_prefix}/latest",
+        # XXX                 headers=gh_headers).json["assets"][0]
+        # XXX sh.wget(
+        # XXX     f"{gh_prefix}/assets/{asset['id']}",
+        # XXX     "-O",
+        # XXX     asset["name"],
+        # XXX     "--header",
+        # XXX     "Accept: application/octet-stream",
+        # XXX     "--header",
+        # XXX     f"Authorization: {gh_token_header}",
+        # XXX     _cwd=home_dir,
+        # XXX )
+        # XXX sh.sh(
+        # XXX     "runinenv",
+        # XXX     "system/env",
+        # XXX     "pip",
+        # XXX     "install",
+        # XXX     # TODO "--index-url",
+        # XXX     # TODO "",
+        # XXX     # TODO "--extra-index-url",
+        # XXX     # TODO "",
+        # XXX     asset["name"],
+        # XXX     _cwd=home_dir,
+        # XXX )
+    else:  # PyPI package
+        sh.sh(
+            "runinenv",
+            "system/env",
+            "pip",
+            "install",
+            # TODO "--index-url",
+            # TODO "",
+            # TODO "--extra-index-url",
+            # TODO "",
+            app,
             _cwd=home_dir,
         )
-        sh.sh("runinenv", "system/env", "pip", "install", asset["name"], _cwd=home_dir)
-    else:  # PyPI package
-        sh.sh("runinenv", "system/env", "pip", "install", app, _cwd=home_dir)
     sh.sudo("supervisorctl", "restart", "gaea-app", "gaea-app-jobs")
 
 
